@@ -1,48 +1,10 @@
 package Email::MIME::Kit::Renderer::TestRenderer;
+our $VERSION = '2.091410';
+
 use Moose;
 with 'Email::MIME::Kit::Role::Renderer';
+# ABSTRACT:  extremely simple renderer for testing purposes only
 
-=head1 NAME
-
-Email::MIME::Kit::Renderer::TestRenderer - extremely simple renderer for testing purposes only
-
-=cut
-
-our $VERSION = '2.004';
-
-=head1 WARNING
-
-Seriously, this is horrible code.  If you want, look at it.  It's swell for
-testing simple things, but if you use this for real mkits, you're going to be
-upset by something horrible soon.
-
-=head1 DESCRIPTION
-
-The test renderer is like a version of Template Toolkit 2 that has had a crayon
-shoved up its nose and into its brain.  It can only do a very things, but it
-does them well enough to test simple kits.
-
-Given the following template:
-
-  This will say "I love pie": [% actor %] [% m_obj.verb() %] [% z_by("me") %]
-
-...and the following set of variables:
-
-  {
-    actor => 'I',
-    m_obj => $object_whose_verb_method_returns_love,
-    z_by  => sub { 'me' },
-  }
-
-..then it will be a true statement.
-
-In method calls, the parens are B<not> optional.  Anything between them (or
-between the parens in a coderef call) is evaluated like perl code.  For
-example, this will actually get the OS:
-
-  [% z_by($^O) %]
-
-=cut
 
 sub render {
   my ($self, $content_ref, $stash) = @_;
@@ -62,3 +24,62 @@ sub render {
 
 no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::MIME::Kit::Renderer::TestRenderer - extremely simple renderer for testing purposes only
+
+=head1 VERSION
+
+version 2.091410
+
+=head1 WARNING
+
+Seriously, this is horrible code.  If you want, look at it.  It's swell for
+testing simple things, but if you use this for real mkits, you're going to be
+upset by something horrible soon.
+
+=head1 DESCRIPTION
+
+The test renderer is like a version of Template Toolkit 2 that has had a crayon
+shoved up its nose and into its brain.  It can only do a very few things, but
+it does them well enough to test simple kits.
+
+Given the following template:
+
+    This will say "I love pie": [% actor %] [% m_obj.verb() %] [% z_by("me") %]
+
+...and the following set of variables:
+
+    {
+      actor => 'I',
+      m_obj => $object_whose_verb_method_returns_love,
+      z_by  => sub { 'me' },
+    }
+
+..then it will be a true statement.
+
+In method calls, the parens are B<not> optional.  Anything between them (or
+between the parens in a coderef call) is evaluated like perl code.  For
+example, this will actually get the OS:
+
+    [% z_by($^O) %]
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
